@@ -1,5 +1,5 @@
 package ZMQ::FFI::ZMQ3::Context;
-$ZMQ::FFI::ZMQ3::Context::VERSION = '1.09';
+$ZMQ::FFI::ZMQ3::Context::VERSION = '1.10';
 use FFI::Platypus;
 use ZMQ::FFI::Util qw(zmq_soname current_tid);
 use ZMQ::FFI::Constants qw(ZMQ_IO_THREADS ZMQ_MAX_SOCKETS);
@@ -26,12 +26,7 @@ sub BUILD {
     }
 
     try {
-        # XXX
-        # not clear why this is necessary, but the setter doesn't actually
-        # take affect if you directly nest the zmq_ctx_new call in the _ctx
-        # call... some Class::XSAccessor weirdness/bug? Need to investigate.
-        my $c = zmq_ctx_new();
-        $self->context_ptr($c);
+        $self->context_ptr( zmq_ctx_new() );
         $self->check_null('zmq_ctx_new', $self->context_ptr);
     }
     catch {
@@ -209,7 +204,7 @@ ZMQ::FFI::ZMQ3::Context
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 AUTHOR
 
@@ -217,7 +212,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dylan Cali.
+This software is copyright (c) 2016 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
